Description Usage Arguments Value
View source: R/perturb_analysis.R
Compute sensitivity
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 | sensitivity(
ipm,
what = c("r_0", "lambda", "gen_t"),
level = c("kernel", "vital_rate", "parameter"),
subset = NA_character_,
...
)
## S3 method for class 'simple_di_det_ipm'
sensitivity(
ipm,
what = "lambda",
level = "kernel",
subset = NA_character_,
n_iterations = 100,
...
)
## S3 method for class 'general_di_det_ipm'
sensitivity(
ipm,
what = "lambda",
level = "kernel",
subset = NA_character_,
n_iterations = 100L,
mega_mat,
mega_vec,
...
)
|
ipm |
Output from |
what |
The numerator of the partial derivative for sensitivity.
Possible options |
level |
The denominator of the partial derivative for sensitivity.
|
subset |
A character vector corresponding to the |
... |
other arguments passed to methods. |
n_iterations |
For simple IPMs, number of times to iterate the model when computing the left and right eigenvectors. |
mega_mat |
A vector of names and/or 0s specifying the relationship
between the kernels in the model. The names should correspond to kernel
names, with 0s corresponding to sparse areas of the mega-matrix. The names can
be either symbols or characters. These functions support suffix expansion as in
|
mega_vec |
A vector of names specifying the format of the population vector. The names can be either symbols or characters. |
A list. Contains either kernel response surfaces, vital rate level
sensitivity values, or parameter level sensitivity values. The class is always
c("ipmr_sensitivity", "list") (for internal usage and plot methods).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.